==> piwigo-2.9.2.zip: piwigo/plugins/TakeATour/language/eo_EO/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['First Contact'] = 'Unua kontakto';
$lang['Start the Tour'] = 'Komenci la traviziton';
$lang['Visit your Piwigo!'] = 'Vizitu vian Piwigo-n!';
$lang['TAT_descrp'] = 'Bonvenon! Jen listiĝas ĉiuj travizitoj disponeblaj por malkovri la trajtojn de via Piwigo-galerio. <br> Lanĉu traviziton malsupre, kaj sekvu la instrukciojn. Alklaku sur Sekva/Antaŭa (aŭ uzu la sagojn de la klavaro) por navigi dum travizito. Dum travizito, se vi iras al alia paĝo de la administraĵo, vi estos alidirektita al la aktuala paĝo de la travizito. Se vi estas blokita kaj ne povas fini la traviziton, iri al <em>Kromprogramoj » Traviziti</ em> finos la viziton.';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Travizitu kaj malkovru la trajtojn de via Piwigo-galerio » Iru al la disponeblaj travizitoj';
$lang['End tour'] = 'Finu la traviziton';
$lang['Prev'] = 'Antaŭa';
$lang['Next '] = 'Sekvanta';

$lang['2.7 Tour'] = 'Travizito 2.7';
$lang['2_7_0_descrp'] = 'Malkovru tion, kio novas en Piwigo 2.7';
$lang['first_contact_descrp'] = 'Konsilita al komencantoj, tiu travizito konigas al vi na Piwigo kaj ĝia bazaj trajtoj. Ĝi komenciĝos montrante al vi kiel aldoni fotojn, kaj sekve mastrumi ilin. La travizito daŭras per fotara mastrumado kaj finas per tajlorado uzante konfiguradon, temojn kaj kromaĵojn.';
$lang['privacy_descrp'] = 'Tiu travizito prezentas ĉiujn metodojn por protekti viajn fotojn el publika atingo kun fotaro- kaj foto-permesoj, kaj el kopiado uzante bildoprotektojn.';
$lang['takeatour_configpage'] = 'Travizitu » Listo de Travizitoj';
$lang['Privacy'] = 'Privateco';
$lang['2_8_0_descrp'] = 'Malkovru kelkajn novajn funkciojn de Piwigo 2.8. Legu detalojn sur la <a href="%s">notoj de versio</a>. ';
$lang['2_9_0_descrp'] = 'Malkovru kelkajn novajn funkciojn de Piwigo 2.9. Legu detalojn sur la <a href="%s">notoj de versio</a>. ';
$lang['edit_photos_name'] = 'Redakti la fotojn';
$lang['manage_albums_name'] = 'Mastrumi la albumojn';
$lang['2.8 Tour'] = 'Versio 2.8';
$lang['2_9_0_name'] = 'Version 2.9';
$lang['config_name'] = 'Agordo';
$lang['plugins_name'] = 'Kromprogramoj';

==> piwigo-15.6.0.zip: piwigo/plugins/TakeATour/language/eo_EO/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['First Contact'] = 'Unua kontakto';
$lang['Start the Tour'] = 'Komenci la traviziton';
$lang['Visit your Piwigo!'] = 'Vizitu vian Piwigo-n!';
$lang['TAT_descrp'] = 'Bonvenon! Jen listiĝas ĉiuj travizitoj disponeblaj por malkovri la trajtojn de via Piwigo-galerio. <br> Lanĉu traviziton malsupre, kaj sekvu la instrukciojn. Alklaku sur Sekva/Antaŭa (aŭ uzu la sagojn de la klavaro) por navigi dum travizito. Dum travizito, se vi iras al alia paĝo de la administraĵo, vi estos alidirektita al la aktuala paĝo de la travizito. Se vi estas blokita kaj ne povas fini la traviziton, iri al <em>Kromprogramoj » Traviziti</ em> finos la viziton.';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Travizitu kaj malkovru la trajtojn de via Piwigo-galerio » Iru al la disponeblaj travizitoj';
$lang['End tour'] = 'Finu la traviziton';
$lang['Prev'] = 'Antaŭa';
$lang['Next '] = 'Sekvanta';

$lang['2.7 Tour'] = 'Travizito 2.7';
$lang['2_7_0_descrp'] = 'Malkovru tion, kio novas en Piwigo 2.7';
$lang['first_contact_descrp'] = 'Konsilita al komencantoj, tiu travizito konigas al vi na Piwigo kaj ĝia bazaj trajtoj. Ĝi komenciĝos montrante al vi kiel aldoni fotojn, kaj sekve mastrumi ilin. La travizito daŭras per fotara mastrumado kaj finas per tajlorado uzante konfiguradon, temojn kaj kromaĵojn.';
$lang['privacy_descrp'] = 'Tiu travizito prezentas ĉiujn metodojn por protekti viajn fotojn el publika atingo kun fotaro- kaj foto-permesoj, kaj el kopiado uzante bildoprotektojn.';
$lang['takeatour_configpage'] = 'Travizitu » Listo de Travizitoj';
$lang['Privacy'] = 'Privateco';
$lang['2_8_0_descrp'] = 'Malkovru kelkajn novajn funkciojn de Piwigo 2.8. Legu detalojn sur la <a href="%s">notoj de versio</a>. ';
$lang['2_9_0_descrp'] = 'Malkovru kelkajn novajn funkciojn de Piwigo 2.9. Legu detalojn sur la <a href="%s">notoj de versio</a>. ';
$lang['edit_photos_name'] = 'Redakti la fotojn';
$lang['manage_albums_name'] = 'Mastrumi la albumojn';
$lang['2.8 Tour'] = 'Versio 2.8';
$lang['2_9_0_name'] = 'Version 2.9';
$lang['config_name'] = 'Agordo';
$lang['plugins_name'] = 'Kromprogramoj';
$lang['config_descrp'] = 'Agordi vian Piwigon. Malkovru la administrilon de etosoj kaj elektu la aspekton de via Piwigo.';
$lang['edit_photos_descrp'] = 'Fotoj estas baza elemento en via Piwigo. Vidu kiel ŝanĝi ĝiajn ecojn, unu post la alia aŭ grupe.';
$lang['plugins_descrp'] = 'Kromprogramoj estas ĉefa funkcio de Piwigo. Aktivigu diversajn funkciojn per nur kelkaj musklakoj kaj adaptu Piwigo al viaj bezonoj.';
$lang['manage_albums_descrp'] = 'La albuma hierarkio estas la strukturo de via galerio. Lernu kiel organizi ilin kaj redakti iliajn ecojn.';
